@@ -1,3 +1,7 @@
+from functools import total_ordering
+
+
+@total_ordering
 class IamPolicy(object):
     def __init__(self, name, document):
         assert isinstance(name, unicode)
@@ -21,3 +25,12 @@ class IamPolicy(object):
             unicode
         """
         return self._document
+
+    def __eq__(self, other):
+        return (self.name == other.name)
+
+    def __lt__(self, other):
+        return (self.name < other.name)
+
+    def __hash__(self):
+        return hash((self.__class__, self.name))
